
#ifndef SCIENCE_EXPORT_H
#define SCIENCE_EXPORT_H

#ifdef SCIENCE_STATIC_DEFINE
#  define SCIENCE_EXPORT
#  define SCIENCE_NO_EXPORT
#else
#  ifndef SCIENCE_EXPORT
#    ifdef science_EXPORTS
        /* We are building this library */
#      define SCIENCE_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define SCIENCE_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef SCIENCE_NO_EXPORT
#    define SCIENCE_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef SCIENCE_DEPRECATED
#  define SCIENCE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef SCIENCE_DEPRECATED_EXPORT
#  define SCIENCE_DEPRECATED_EXPORT SCIENCE_EXPORT SCIENCE_DEPRECATED
#endif

#ifndef SCIENCE_DEPRECATED_NO_EXPORT
#  define SCIENCE_DEPRECATED_NO_EXPORT SCIENCE_NO_EXPORT SCIENCE_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef SCIENCE_NO_DEPRECATED
#    define SCIENCE_NO_DEPRECATED
#  endif
#endif

#endif /* SCIENCE_EXPORT_H */
